@@ -18,7 +18,6 @@
  */
 import { t } from '../translation';
 import { removeDuplicates } from '../utils';
-import { DTTM_ALIAS } from './constants';
 import getColumnLabel from './getColumnLabel';
 import getMetricLabel from './getMetricLabel';
 import {
@@ -30,7 +29,6 @@ import {
   FormDataResidual,
   QueryMode,
 } from './types/QueryFormData';
-import { hasGenericChartAxes } from './getXAxis';
 
 /**
  * Extra SQL query related fields from chart form data.
@@ -57,11 +55,7 @@ export default function extractQueryFields(
     order_by_cols: 'orderby',
     ...aliases,
   };
-  const {
-    query_mode: queryMode,
-    include_time: includeTime,
-    ...restFormData
-  } = formData;
+  const { query_mode: queryMode, ...restFormData } = formData;
 
   let columns: QueryFormColumn[] = [];
   let metrics: QueryFormMetric[] = [];
@@ -79,13 +73,13 @@ export default function extractQueryFields(
     // For charts that support both aggregate and raw records mode,
     // we store both `groupby` and `columns` in `formData`, so users can
     // switch between modes while retaining the selected options for each.
-    if (queryMode === QueryMode.aggregate && normalizedKey === 'columns') {
+    if (queryMode === QueryMode.Aggregate && normalizedKey === 'columns') {
       return;
     }
 
     // for the same reason, ignore groupby and metrics in raw records mode
     if (
-      queryMode === QueryMode.raw &&
+      queryMode === QueryMode.Raw &&
       (normalizedKey === 'groupby' || normalizedKey === 'metrics')
     ) {
       return;
@@ -106,17 +100,13 @@ export default function extractQueryFields(
     }
   });
 
-  if (!hasGenericChartAxes && includeTime && !columns.includes(DTTM_ALIAS)) {
-    columns.unshift(DTTM_ALIAS);
-  }
-
   return {
     columns: removeDuplicates(
       columns.filter(col => col !== ''),
       getColumnLabel,
     ),
     metrics:
-      queryMode === QueryMode.raw
+      queryMode === QueryMode.Raw
         ? undefined
         : removeDuplicates(metrics, getMetricLabel),
     orderby:
