@@ -16,6 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
+import { NumberFormatter } from '../number-format';
+import { CurrencyFormatter } from '../currency-format';
+
 export * from '../query/types';
 
 export type Maybe<T> = T | null;
@@ -23,3 +26,5 @@ export type Maybe<T> = T | null;
 export type Optional<T> = T | undefined;
 
 export type ValueOf<T> = T[keyof T];
+
+export type ValueFormatter = NumberFormatter | CurrencyFormatter;
