@@ -17,7 +17,12 @@
  * under the License.
  */
 
-import { getContrastingColor, addAlpha } from '@superset-ui/core';
+import {
+  getContrastingColor,
+  addAlpha,
+  hexToRgb,
+  rgbToHex,
+} from '@superset-ui/core';
 
 describe('color utils', () => {
   describe('getContrastingColor', () => {
@@ -82,4 +87,23 @@ describe('color utils', () => {
       }).toThrow();
     });
   });
+  describe('hexToRgb', () => {
+    it('convert 3 digits hex', () => {
+      expect(hexToRgb('#fff')).toBe('rgb(255, 255, 255)');
+    });
+    it('convert 6 digits hex', () => {
+      expect(hexToRgb('#ffffff')).toBe('rgb(255, 255, 255)');
+    });
+    it('convert invalid hex', () => {
+      expect(hexToRgb('#ffffffffffffff')).toBe('rgb(0, 0, 0)');
+    });
+  });
+  describe('rgbToHex', () => {
+    it('convert rgb to hex - white', () => {
+      expect(rgbToHex(255, 255, 255)).toBe('#ffffff');
+    });
+    it('convert rgb to hex - black', () => {
+      expect(rgbToHex(0, 0, 0)).toBe('#000000');
+    });
+  });
 });
