@@ -16,33 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import {
-  FeatureFlag,
-  isFeatureEnabled,
-  t,
-  validateMapboxStylesUrl,
-} from '@superset-ui/core';
+import { t, validateMapboxStylesUrl } from '@superset-ui/core';
 import {
   columnChoices,
   ControlPanelConfig,
-  ControlPanelState,
   formatSelectOptions,
-  sections,
   sharedControls,
   getStandardizedControls,
 } from '@superset-ui/chart-controls';
 
-const allColumns = {
-  type: 'SelectControl',
-  default: null,
-  mapStateToProps: (state: ControlPanelState) => ({
-    choices: columnChoices(state.datasource),
-  }),
-};
-
-const columnsConfig = isFeatureEnabled(FeatureFlag.ENABLE_EXPLORE_DRAG_AND_DROP)
-  ? sharedControls.entity
-  : allColumns;
+const columnsConfig = sharedControls.entity;
 
 const colorChoices = [
   ['rgb(0, 139, 139)', t('Dark Cyan')],
@@ -55,7 +38,6 @@ const colorChoices = [
 
 const config: ControlPanelConfig = {
   controlPanelSections: [
-    sections.legacyRegularTime,
     {
       label: t('Query'),
       expanded: true,
