@@ -21,3 +21,9 @@
 
 export type Range = [number, number];
 export type Point = [number, number];
+export interface ColorType {
+  r: number;
+  g: number;
+  b: number;
+  a: number;
+}
