@@ -19,7 +19,11 @@
 import d3 from 'd3';
 import d3tip from 'd3-tip';
 import dompurify from 'dompurify';
-import { smartDateFormatter, getNumberFormatter } from '@superset-ui/core';
+import {
+  SMART_DATE_ID,
+  getTimeFormatter,
+  getNumberFormatter,
+} from '@superset-ui/core';
 // Regexp for the label added to time shifted series
 // (1 hour offset, 2 days offset, etc.)
 const TIME_SHIFT_PATTERN = /\d+ \w+ offset/;
@@ -42,8 +46,8 @@ export function cleanColorInput(value) {
  * @param {*} format
  */
 export function getTimeOrNumberFormatter(format) {
-  return format === 'smart_date'
-    ? smartDateFormatter
+  return format === SMART_DATE_ID
+    ? getTimeFormatter(SMART_DATE_ID)
     : getNumberFormatter(format);
 }
 
