@@ -41,9 +41,8 @@ const metadata = {
     t('Business'),
     t('Legacy'),
     t('Percentages'),
-    t('Popular'),
+    t('Featured'),
     t('Report'),
-    t('Description'),
   ],
   thumbnail,
   behaviors: [Behavior.DrillToDetail],
