@@ -39,9 +39,8 @@ const metadata = {
     t('Advanced-Analytics'),
     t('Line'),
     t('Percentages'),
-    t('Popular'),
+    t('Featured'),
     t('Report'),
-    t('Description'),
     t('Trend'),
   ],
   thumbnail,
