@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import React, {
+import {
   useRef,
   useEffect,
   useMemo,
@@ -24,9 +24,41 @@ import React, {
   useImperativeHandle,
   useLayoutEffect,
   useCallback,
+  Ref,
 } from 'react';
+
 import { styled } from '@superset-ui/core';
-import { ECharts, init } from 'echarts';
+import { use, init, EChartsType } from 'echarts/core';
+import {
+  SankeyChart,
+  PieChart,
+  BarChart,
+  FunnelChart,
+  GaugeChart,
+  GraphChart,
+  LineChart,
+  ScatterChart,
+  RadarChart,
+  BoxplotChart,
+  TreeChart,
+  TreemapChart,
+  HeatmapChart,
+  SunburstChart,
+} from 'echarts/charts';
+import { CanvasRenderer } from 'echarts/renderers';
+import {
+  TooltipComponent,
+  GridComponent,
+  VisualMapComponent,
+  LegendComponent,
+  DataZoomComponent,
+  ToolboxComponent,
+  GraphicComponent,
+  AriaComponent,
+  MarkAreaComponent,
+  MarkLineComponent,
+} from 'echarts/components';
+import { LabelLayout } from 'echarts/features';
 import { EchartsHandler, EchartsProps, EchartsStylesProps } from '../types';
 
 const Styles = styled.div<EchartsStylesProps>`
@@ -34,6 +66,35 @@ const Styles = styled.div<EchartsStylesProps>`
   width: ${({ width }) => width};
 `;
 
+use([
+  CanvasRenderer,
+  BarChart,
+  BoxplotChart,
+  FunnelChart,
+  GaugeChart,
+  GraphChart,
+  HeatmapChart,
+  LineChart,
+  PieChart,
+  RadarChart,
+  SankeyChart,
+  ScatterChart,
+  SunburstChart,
+  TreeChart,
+  TreemapChart,
+  AriaComponent,
+  DataZoomComponent,
+  GraphicComponent,
+  GridComponent,
+  MarkAreaComponent,
+  MarkLineComponent,
+  LegendComponent,
+  ToolboxComponent,
+  TooltipComponent,
+  VisualMapComponent,
+  LabelLayout,
+]);
+
 function Echart(
   {
     width,
@@ -44,14 +105,14 @@ function Echart(
     selectedValues = {},
     refs,
   }: EchartsProps,
-  ref: React.Ref<EchartsHandler>,
+  ref: Ref<EchartsHandler>,
 ) {
   const divRef = useRef<HTMLDivElement>(null);
   if (refs) {
     // eslint-disable-next-line no-param-reassign
     refs.divRef = divRef;
   }
-  const chartRef = useRef<ECharts>();
+  const chartRef = useRef<EChartsType>();
   const currentSelection = useMemo(
     () => Object.keys(selectedValues) || [],
     [selectedValues],
