@@ -18,6 +18,7 @@
  */
 import fetchMock from 'fetch-mock';
 import { act, renderHook } from '@testing-library/react-hooks';
+import { getExtensionsRegistry } from '@superset-ui/core';
 import {
   createWrapper,
   defaultStore as store,
@@ -60,6 +61,7 @@ const fakeFunctionNamesApiResult = {
 };
 
 const expectDbId = 1;
+const expectCatalog = null;
 const expectSchema = 'schema1';
 
 beforeEach(() => {
@@ -188,7 +190,12 @@ test('returns column keywords among selected tables', async () => {
     storeWithSqlLab.dispatch(
       tableApiUtil.upsertQueryData(
         'tableMetadata',
-        { dbId: expectDbId, schema: expectSchema, table: expectTable },
+        {
+          dbId: expectDbId,
+          catalog: null,
+          schema: expectSchema,
+          table: expectTable,
+        },
         {
           name: expectTable,
           columns: [
@@ -204,7 +211,12 @@ test('returns column keywords among selected tables', async () => {
     storeWithSqlLab.dispatch(
       tableApiUtil.upsertQueryData(
         'tableMetadata',
-        { dbId: expectDbId, schema: expectSchema, table: unexpectedTable },
+        {
+          dbId: expectDbId,
+          catalog: null,
+          schema: expectSchema,
+          table: unexpectedTable,
+        },
         {
           name: unexpectedTable,
           columns: [
@@ -217,7 +229,12 @@ test('returns column keywords among selected tables', async () => {
       ),
     );
     storeWithSqlLab.dispatch(
-      addTable({ id: expectQueryEditorId }, expectTable, expectSchema),
+      addTable(
+        { id: expectQueryEditorId },
+        expectTable,
+        expectCatalog,
+        expectSchema,
+      ),
     );
   });
 
@@ -226,6 +243,7 @@ test('returns column keywords among selected tables', async () => {
       useKeywords({
         queryEditorId: expectQueryEditorId,
         dbId: expectDbId,
+        catalog: null,
         schema: expectSchema,
       }),
     {
@@ -255,7 +273,12 @@ test('returns column keywords among selected tables', async () => {
 
   act(() => {
     storeWithSqlLab.dispatch(
-      addTable({ id: expectQueryEditorId }, unexpectedTable, expectSchema),
+      addTable(
+        { id: expectQueryEditorId },
+        unexpectedTable,
+        expectCatalog,
+        expectSchema,
+      ),
     );
   });
 
@@ -313,3 +336,43 @@ test('returns long keywords with docText', async () => {
     ),
   );
 });
+
+test('Add custom keywords for autocomplete', () => {
+  const expected = [
+    {
+      name: 'Custom keyword 1',
+      label: 'Custom keyword 1',
+      meta: 'Custom',
+      value: 'custom1',
+      score: 100,
+    },
+    {
+      name: 'Custom keyword 2',
+      label: 'Custom keyword 2',
+      meta: 'Custom',
+      value: 'custom2',
+      score: 50,
+    },
+  ];
+  const extensionsRegistry = getExtensionsRegistry();
+  extensionsRegistry.set(
+    'sqleditor.extension.customAutocomplete',
+    () => expected,
+  );
+  const { result } = renderHook(
+    () =>
+      useKeywords({
+        queryEditorId: 'testqueryid',
+        dbId: expectDbId,
+        schema: expectSchema,
+      }),
+    {
+      wrapper: createWrapper({
+        useRedux: true,
+        store,
+      }),
+    },
+  );
+  expect(result.current).toContainEqual(expect.objectContaining(expected[0]));
+  expect(result.current).toContainEqual(expect.objectContaining(expected[1]));
+});
