@@ -16,7 +16,8 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import React, { FunctionComponent, useState, useRef } from 'react';
+import { FunctionComponent, useState, useRef, ChangeEvent } from 'react';
+
 import SchemaForm, { FormProps, FormValidation } from 'react-jsonschema-form';
 import { Row, Col } from 'src/components';
 import { Input, TextArea } from 'src/components/Input';
@@ -46,7 +47,9 @@ const getJSONSchema = () => {
         if (value.default && value.format === 'date-time') {
           jsonSchema.properties[key] = {
             ...value,
-            default: chrono.parseDate(value.default).toISOString(),
+            default: value.default
+              ? chrono.parseDate(value.default)?.toISOString()
+              : null,
           };
         }
       },
@@ -171,7 +174,7 @@ const ScheduleQueryButton: FunctionComponent<ScheduleQueryButtonProps> = ({
               type="text"
               placeholder={t('Label for your query')}
               value={label}
-              onChange={(event: React.ChangeEvent<HTMLInputElement>) =>
+              onChange={(event: ChangeEvent<HTMLInputElement>) =>
                 setLabel(event.target.value)
               }
             />
@@ -185,7 +188,7 @@ const ScheduleQueryButton: FunctionComponent<ScheduleQueryButtonProps> = ({
               rows={4}
               placeholder={t('Write a description for your query')}
               value={description}
-              onChange={(event: React.ChangeEvent<HTMLTextAreaElement>) =>
+              onChange={(event: ChangeEvent<HTMLTextAreaElement>) =>
                 setDescription(event.target.value)
               }
             />
