@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import pick from 'lodash/pick';
+import { pick } from 'lodash';
 import { shallowEqual, useSelector } from 'react-redux';
 import { SqlLabRootState, QueryEditor } from 'src/SqlLab/types';
 
