@@ -16,12 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import React, {
+import {
   createRef,
   forwardRef,
   useImperativeHandle,
   useMemo,
+  RefObject,
 } from 'react';
+
 import { withTheme } from '@superset-ui/core';
 
 import {
@@ -43,7 +45,7 @@ interface UIFiltersProps {
 
 function UIFilters(
   { filters, internalFilters = [], updateFilterValue }: UIFiltersProps,
-  ref: React.RefObject<{ clearFilters: () => void }>,
+  ref: RefObject<{ clearFilters: () => void }>,
 ) {
   const filterRefs = useMemo(
     () =>
