@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import React from 'react';
 import { styledMount as mount } from 'spec/helpers/theming';
 import { act } from 'react-dom/test-utils';
 import { QueryParamProvider } from 'use-query-params';
@@ -152,12 +151,12 @@ describe('ListView', () => {
     expect(wrapper.find(ListView)).toExist();
     expect(mockedProps.fetchData.mock.calls[0]).toMatchInlineSnapshot(
       `
-        Array [
-          Object {
-            "filters": Array [],
+        [
+          {
+            "filters": [],
             "pageIndex": 0,
             "pageSize": 1,
-            "sortBy": Array [],
+            "sortBy": [],
           },
         ]
       `,
@@ -169,13 +168,13 @@ describe('ListView', () => {
     expect(mockedProps.fetchData).toHaveBeenCalled();
     expect(mockedProps.fetchData.mock.calls[0]).toMatchInlineSnapshot(
       `
-        Array [
-          Object {
-            "filters": Array [],
+        [
+          {
+            "filters": [],
             "pageIndex": 0,
             "pageSize": 1,
-            "sortBy": Array [
-              Object {
+            "sortBy": [
+              {
                 "desc": false,
                 "id": "id",
               },
@@ -200,13 +199,13 @@ describe('ListView', () => {
     wrapper.update();
 
     expect(mockedProps.fetchData.mock.calls[0]).toMatchInlineSnapshot(`
-      Array [
-        Object {
-          "filters": Array [],
+      [
+        {
+          "filters": [],
           "pageIndex": 1,
           "pageSize": 1,
-          "sortBy": Array [
-            Object {
+          "sortBy": [
+            {
               "desc": false,
               "id": "id",
             },
@@ -234,9 +233,9 @@ describe('ListView', () => {
 
     expect(mockedProps.bulkActions[0].onSelect.mock.calls[0])
       .toMatchInlineSnapshot(`
-      Array [
-        Array [
-          Object {
+      [
+        [
+          {
             "age": 10,
             "id": 1,
             "name": "data 1",
@@ -265,15 +264,15 @@ describe('ListView', () => {
 
     expect(mockedProps.bulkActions[0].onSelect.mock.calls[0])
       .toMatchInlineSnapshot(`
-      Array [
-        Array [
-          Object {
+      [
+        [
+          {
             "age": 10,
             "id": 1,
             "name": "data 1",
             "time": "2020-11-18T07:53:45.354Z",
           },
-          Object {
+          {
             "age": 1,
             "id": 2,
             "name": "data 2",
@@ -407,13 +406,13 @@ describe('ListView', () => {
     });
 
     expect(mockedProps.fetchData.mock.calls[0]).toMatchInlineSnapshot(`
-      Array [
-        Object {
-          "filters": Array [
-            Object {
+      [
+        {
+          "filters": [
+            {
               "id": "id",
               "operator": "eq",
-              "value": Object {
+              "value": {
                 "label": "bar",
                 "value": "bar",
               },
@@ -421,8 +420,8 @@ describe('ListView', () => {
           ],
           "pageIndex": 0,
           "pageSize": 1,
-          "sortBy": Array [
-            Object {
+          "sortBy": [
+            {
               "desc": false,
               "id": "id",
             },
@@ -432,18 +431,18 @@ describe('ListView', () => {
     `);
 
     expect(mockedProps.fetchData.mock.calls[1]).toMatchInlineSnapshot(`
-      Array [
-        Object {
-          "filters": Array [
-            Object {
+      [
+        {
+          "filters": [
+            {
               "id": "id",
               "operator": "eq",
-              "value": Object {
+              "value": {
                 "label": "bar",
                 "value": "bar",
               },
             },
-            Object {
+            {
               "id": "name",
               "operator": "ct",
               "value": "something",
@@ -451,8 +450,8 @@ describe('ListView', () => {
           ],
           "pageIndex": 0,
           "pageSize": 1,
-          "sortBy": Array [
-            Object {
+          "sortBy": [
+            {
               "desc": false,
               "id": "id",
             },
