@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import React from 'react';
 import Button from 'src/components/Button';
 import { TooltipProps, TooltipPlacement } from 'antd/lib/tooltip';
 import { Tooltip } from './index';
@@ -58,11 +57,13 @@ InteractiveTooltip.args = {
 InteractiveTooltip.argTypes = {
   placement: {
     defaultValue: 'top',
-    control: { type: 'select', options: PLACEMENTS },
+    control: { type: 'select' },
+    options: PLACEMENTS,
   },
   trigger: {
     defaultValue: 'hover',
-    control: { type: 'select', options: TRIGGERS },
+    control: { type: 'select' },
+    options: TRIGGERS,
   },
   color: { control: { type: 'color' } },
   onVisibleChange: { action: 'onVisibleChange' },
