@@ -17,7 +17,6 @@
  * under the License.
  */
 
-import React from 'react';
 import {
   styled,
   css,
@@ -29,6 +28,7 @@ import { CrossFilterIndicator } from 'src/dashboard/components/nativeFilters/sel
 import { Tag } from 'src/components';
 import { Tooltip } from 'src/components/Tooltip';
 import { FilterBarOrientation } from 'src/dashboard/types';
+import { CustomCloseIcon } from 'src/components/Tags/Tag';
 import { ellipsisCss } from './styles';
 
 const StyledCrossFilterValue = styled.b`
@@ -68,6 +68,7 @@ const CrossFilterTag = (props: {
   const [valueRef, valueIsTruncated] = useCSSTextTruncation<HTMLSpanElement>();
 
   const columnLabel = getColumnLabel(filter.column ?? '');
+
   return (
     <StyledTag
       css={css`
@@ -81,6 +82,7 @@ const CrossFilterTag = (props: {
       `}
       closable
       onClose={() => removeCrossFilter(filter.emitterId)}
+      closeIcon={CustomCloseIcon}
     >
       <Tooltip title={columnIsTruncated ? columnLabel : null}>
         <StyledCrossFilterColumn ref={columnRef}>
