@@ -16,7 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import React, { useEffect, Dispatch, useReducer } from 'react';
+import {
+  createContext,
+  useEffect,
+  useState,
+  Dispatch,
+  FC,
+  useReducer,
+} from 'react';
+
 import { styled } from '@superset-ui/core';
 import { useDragDropManager } from 'react-dnd';
 import { DatasourcePanelDndItem } from '../DatasourcePanel/types';
@@ -25,10 +33,11 @@ type CanDropValidator = (item: DatasourcePanelDndItem) => boolean;
 type DropzoneSet = Record<string, CanDropValidator>;
 type Action = { key: string; canDrop?: CanDropValidator };
 
-export const DraggingContext = React.createContext(false);
-export const DropzoneContext = React.createContext<
-  [DropzoneSet, Dispatch<Action>]
->([{}, () => {}]);
+export const DraggingContext = createContext(false);
+export const DropzoneContext = createContext<[DropzoneSet, Dispatch<Action>]>([
+  {},
+  () => {},
+]);
 const StyledDiv = styled.div`
   display: flex;
   flex-direction: column;
@@ -51,9 +60,9 @@ const reducer = (state: DropzoneSet = {}, action: Action) => {
   return state;
 };
 
-const ExploreContainer: React.FC<{}> = ({ children }) => {
+const ExploreContainer: FC<{}> = ({ children }) => {
   const dragDropManager = useDragDropManager();
-  const [dragging, setDragging] = React.useState(
+  const [dragging, setDragging] = useState(
     dragDropManager.getMonitor().isDragging(),
   );
 
