@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import React, { ReactNode } from 'react';
+import { PureComponent, ReactNode } from 'react';
 import { Metric, t } from '@superset-ui/core';
 import AdhocMetricEditPopoverTitle from 'src/explore/components/controls/MetricControl/AdhocMetricEditPopoverTitle';
 import { ExplorePopoverContent } from 'src/explore/components/ExploreContentPopover';
@@ -57,7 +57,7 @@ export type AdhocMetricPopoverTriggerState = {
   showSaveDatasetModal: boolean;
 };
 
-class AdhocMetricPopoverTrigger extends React.PureComponent<
+class AdhocMetricPopoverTrigger extends PureComponent<
   AdhocMetricPopoverTriggerProps,
   AdhocMetricPopoverTriggerState
 > {
