@@ -16,14 +16,17 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import React, {
+import {
   ChangeEventHandler,
+  FC,
+  ReactElement,
   useCallback,
   useEffect,
   useMemo,
   useRef,
   useState,
 } from 'react';
+
 import Fuse from 'fuse.js';
 import cx from 'classnames';
 import {
@@ -60,62 +63,11 @@ type VizEntry = {
 
 enum Sections {
   AllCharts = 'ALL_CHARTS',
+  Featured = 'FEATURED',
   Category = 'CATEGORY',
   Tags = 'TAGS',
-  RecommendedTags = 'RECOMMENDED_TAGS',
 }
 
-const DEFAULT_ORDER = [
-  'line',
-  'big_number',
-  'big_number_total',
-  'table',
-  'pivot_table_v2',
-  'echarts_timeseries_line',
-  'echarts_area',
-  'echarts_timeseries_bar',
-  'echarts_timeseries_scatter',
-  'pie',
-  'mixed_timeseries',
-  'dist_bar',
-  'area',
-  'bar',
-  'deck_polygon',
-  'time_table',
-  'histogram',
-  'deck_scatter',
-  'deck_hex',
-  'time_pivot',
-  'deck_arc',
-  'heatmap',
-  'deck_grid',
-  'deck_screengrid',
-  'treemap_v2',
-  'box_plot',
-  'sankey',
-  'word_cloud',
-  'mapbox',
-  'kepler',
-  'cal_heatmap',
-  'rose',
-  'bubble',
-  'bubble_v2',
-  'deck_geojson',
-  'horizon',
-  'deck_multi',
-  'compare',
-  'partition',
-  'event_flow',
-  'deck_path',
-  'graph_chart',
-  'world_map',
-  'paired_ttest',
-  'para',
-  'country_map',
-];
-
-const typesWithDefaultOrder = new Set(DEFAULT_ORDER);
-
 const THUMBNAIL_GRID_UNITS = 24;
 
 export const MAX_ADVISABLE_VIZ_GALLERY_WIDTH = 1090;
@@ -124,7 +76,9 @@ const OTHER_CATEGORY = t('Other');
 
 const ALL_CHARTS = t('All charts');
 
-const RECOMMENDED_TAGS = [t('Popular'), t('ECharts'), t('Advanced-Analytics')];
+const FEATURED = t('Featured');
+
+const RECOMMENDED_TAGS = [FEATURED, t('ECharts'), t('Advanced-Analytics')];
 
 export const VIZ_TYPE_CONTROL_TEST_ID = 'viz-type-control';
 
@@ -237,8 +191,8 @@ const SelectorLabel = styled.button`
       }
     }
 
-    & span:first-of-type svg {
-      margin-top: ${theme.gridUnit * 1.5}px;
+    & > span[role="img"] {
+      margin-right: ${theme.gridUnit * 2}px;
     }
 
     .cancel {
@@ -368,13 +322,6 @@ const TitleLabelWrapper = styled.div`
   margin-left: ${({ theme }) => theme.gridUnit * 2}px;
 `;
 
-function vizSortFactor(entry: VizEntry) {
-  if (typesWithDefaultOrder.has(entry.key)) {
-    return DEFAULT_ORDER.indexOf(entry.key);
-  }
-  return DEFAULT_ORDER.length;
-}
-
 interface ThumbnailProps {
   entry: VizEntry;
   selectedViz: string | null;
@@ -382,7 +329,7 @@ interface ThumbnailProps {
   onDoubleClick: () => void;
 }
 
-const Thumbnail: React.FC<ThumbnailProps> = ({
+const Thumbnail: FC<ThumbnailProps> = ({
   entry,
   selectedViz,
   setSelectedViz,
@@ -435,7 +382,7 @@ interface ThumbnailGalleryProps {
 }
 
 /** A list of viz thumbnails, used within the viz picker modal */
-const ThumbnailGallery: React.FC<ThumbnailGalleryProps> = ({
+const ThumbnailGallery: FC<ThumbnailGalleryProps> = ({
   vizEntries,
   ...props
 }) => (
@@ -446,10 +393,10 @@ const ThumbnailGallery: React.FC<ThumbnailGalleryProps> = ({
   </IconsPane>
 );
 
-const Selector: React.FC<{
+const Selector: FC<{
   selector: string;
   sectionId: string;
-  icon: JSX.Element;
+  icon: ReactElement;
   isSelected: boolean;
   onClick: (selector: string, sectionId: string) => void;
   className?: string;
@@ -490,7 +437,7 @@ const doesVizMatchSelector = (viz: ChartMetadata, selector: string) =>
   (viz.tags || []).indexOf(selector) > -1;
 
 export default function VizTypeGallery(props: VizTypeGalleryProps) {
-  const { selectedViz, onChange, onDoubleClick, className } = props;
+  const { selectedViz, onChange, onDoubleClick, className, denyList } = props;
   const { mountedPluginMetadata } = usePluginContext();
   const searchInputRef = useRef<HTMLInputElement>();
   const [searchInputValue, setSearchInputValue] = useState('');
@@ -504,14 +451,14 @@ export default function VizTypeGallery(props: VizTypeGalleryProps) {
   const chartMetadata: VizEntry[] = useMemo(() => {
     const result = Object.entries(mountedPluginMetadata)
       .map(([key, value]) => ({ key, value }))
-      .filter(({ key }) => !props.denyList.includes(key))
+      .filter(({ key }) => !denyList.includes(key))
       .filter(
         ({ value }) =>
           nativeFilterGate(value.behaviors || []) && !value.deprecated,
-      );
-    result.sort((a, b) => vizSortFactor(a) - vizSortFactor(b));
+      )
+      .sort((a, b) => a.value.name.localeCompare(b.value.name));
     return result;
-  }, [mountedPluginMetadata]);
+  }, [mountedPluginMetadata, denyList]);
 
   const chartsByCategory = useMemo(() => {
     const result: Record<string, VizEntry[]> = {};
@@ -563,18 +510,17 @@ export default function VizTypeGallery(props: VizTypeGalleryProps) {
   );
 
   const sortedMetadata = useMemo(
-    () => chartMetadata.sort((a, b) => a.key.localeCompare(b.key)),
+    () =>
+      chartMetadata.sort((a, b) => a.value.name.localeCompare(b.value.name)),
     [chartMetadata],
   );
 
   const [activeSelector, setActiveSelector] = useState<string>(
-    () => selectedVizMetadata?.category || RECOMMENDED_TAGS[0],
+    () => selectedVizMetadata?.category || FEATURED,
   );
 
   const [activeSection, setActiveSection] = useState<string>(() =>
-    selectedVizMetadata?.category
-      ? Sections.Category
-      : Sections.RecommendedTags,
+    selectedVizMetadata?.category ? Sections.Category : Sections.Featured,
   );
 
   // get a fuse instance for fuzzy search
@@ -666,19 +612,14 @@ export default function VizTypeGallery(props: VizTypeGalleryProps) {
 
   const sectionMap = useMemo(
     () => ({
-      [Sections.RecommendedTags]: {
-        title: t('Recommended tags'),
-        icon: <Icons.Tags />,
-        selectors: RECOMMENDED_TAGS,
-      },
       [Sections.Category]: {
         title: t('Category'),
-        icon: <Icons.Category />,
+        icon: <Icons.Category iconSize="m" />,
         selectors: categories,
       },
       [Sections.Tags]: {
         title: t('Tags'),
-        icon: <Icons.Tags />,
+        icon: <Icons.Tags iconSize="m" />,
         selectors: tags,
       },
     }),
@@ -692,17 +633,20 @@ export default function VizTypeGallery(props: VizTypeGalleryProps) {
     if (activeSelector === ALL_CHARTS && activeSection === Sections.AllCharts) {
       return sortedMetadata;
     }
+    if (
+      activeSelector === FEATURED &&
+      activeSection === Sections.Featured &&
+      chartsByTags[FEATURED]
+    ) {
+      return chartsByTags[FEATURED];
+    }
     if (
       activeSection === Sections.Category &&
       chartsByCategory[activeSelector]
     ) {
       return chartsByCategory[activeSelector];
     }
-    if (
-      (activeSection === Sections.Tags ||
-        activeSection === Sections.RecommendedTags) &&
-      chartsByTags[activeSelector]
-    ) {
+    if (activeSection === Sections.Tags && chartsByTags[activeSelector]) {
       return chartsByTags[activeSelector];
     }
     return [];
@@ -724,7 +668,7 @@ export default function VizTypeGallery(props: VizTypeGalleryProps) {
           }
           sectionId={Sections.AllCharts}
           selector={ALL_CHARTS}
-          icon={<Icons.Ballot />}
+          icon={<Icons.Ballot iconSize="m" />}
           isSelected={
             !isActivelySearching &&
             ALL_CHARTS === activeSelector &&
@@ -732,10 +676,28 @@ export default function VizTypeGallery(props: VizTypeGalleryProps) {
           }
           onClick={clickSelector}
         />
+        <Selector
+          css={({ gridUnit }) =>
+            // adjust style for not being inside a collapse
+            css`
+              margin: ${gridUnit * 2}px;
+              margin-bottom: 0;
+            `
+          }
+          sectionId={Sections.Featured}
+          selector={FEATURED}
+          icon={<Icons.FireOutlined iconSize="m" />}
+          isSelected={
+            !isActivelySearching &&
+            FEATURED === activeSelector &&
+            Sections.Featured === activeSection
+          }
+          onClick={clickSelector}
+        />
         <AntdCollapse
           expandIconPosition="right"
           ghost
-          defaultActiveKey={Object.keys(sectionMap)}
+          defaultActiveKey={Sections.Category}
         >
           {Object.keys(sectionMap).map(sectionId => {
             const section = sectionMap[sectionId];
