@@ -23,30 +23,6 @@ class DAOException(SupersetException):
     """
 
 
-class DAOCreateFailedError(DAOException):
-    """
-    DAO Create failed
-    """
-
-    message = "Create failed"
-
-
-class DAOUpdateFailedError(DAOException):
-    """
-    DAO Update failed
-    """
-
-    message = "Update failed"
-
-
-class DAODeleteFailedError(DAOException):
-    """
-    DAO Delete failed
-    """
-
-    message = "Delete failed"
-
-
 class DatasourceTypeNotSupportedError(DAOException):
     """
     DAO datasource query source type is not supported
