@@ -26,6 +26,9 @@ class PinotEngineSpec(BaseEngineSpec):
     engine = "pinot"
     engine_name = "Apache Pinot"
 
+    allows_alias_in_select = False
+    allows_alias_in_orderby = False
+
     # https://docs.pinot.apache.org/users/user-guide-query/supported-transformations#datetime-functions
     _time_grain_expressions = {
         None: "{col}",
