@@ -26,9 +26,6 @@ Create Date: 2018-07-23 11:20:54.929246
 revision = "46ba6aaaac97"
 down_revision = ("705732c70154", "e3970889f38e")
 
-import sqlalchemy as sa
-from alembic import op
-
 
 def upgrade():
     pass
