@@ -26,7 +26,7 @@ Create Date: 2019-07-11 19:02:38.768324
 revision = "def97f26fdfb"
 down_revision = "190188938582"
 
-from alembic import op
+from alembic import op  # noqa: E402
 
 
 def upgrade():
