@@ -26,14 +26,14 @@ Create Date: 2021-11-11 04:18:26.171851
 revision = "0ca9e5f1dacd"
 down_revision = "b92d69a6643c"
 
-import json
-import logging
+import logging  # noqa: E402
 
-from alembic import op
-from sqlalchemy import Column, Integer, Text
-from sqlalchemy.ext.declarative import declarative_base
+from alembic import op  # noqa: E402
+from sqlalchemy import Column, Integer, Text  # noqa: E402
+from sqlalchemy.ext.declarative import declarative_base  # noqa: E402
 
-from superset import db
+from superset import db  # noqa: E402
+from superset.utils import json  # noqa: E402
 
 Base = declarative_base()
 
@@ -51,7 +51,7 @@ def upgrade():
     for database in session.query(Database).all():
         try:
             extra = json.loads(database.extra)
-        except json.decoder.JSONDecodeError as ex:
+        except json.JSONDecodeError as ex:
             logging.warning(str(ex))
             continue
 
@@ -73,7 +73,7 @@ def downgrade():
     for database in session.query(Database).all():
         try:
             extra = json.loads(database.extra)
-        except json.decoder.JSONDecodeError as ex:
+        except json.JSONDecodeError as ex:
             logging.warning(str(ex))
             continue
 
