@@ -26,9 +26,8 @@ Create Date: 2023-06-29 18:38:30.033529
 revision = "240d23c7f86f"
 down_revision = "8e5b0fb85b9a"
 
-import sqlalchemy as sa
-from alembic import op
-from sqlalchemy.dialects import postgresql
+import sqlalchemy as sa  # noqa: E402
+from alembic import op  # noqa: E402
 
 
 def upgrade():
