@@ -25,6 +25,8 @@ Create Date: 2024-04-11 15:41:34.663989
 import sqlalchemy as sa
 from alembic import op
 
+from superset.migrations.shared.utils import add_column_if_not_exists
+
 # revision identifiers, used by Alembic.
 revision = "5f57af97bc3f"
 down_revision = "d60591c5515f"
@@ -34,7 +36,7 @@ tables = ["tables", "query", "saved_query", "tab_state", "table_schema"]
 
 def upgrade():
     for table in tables:
-        op.add_column(
+        add_column_if_not_exists(
             table,
             sa.Column("catalog", sa.String(length=256), nullable=True),
         )
