@@ -18,7 +18,7 @@ from typing import Any
 
 from werkzeug.routing import BaseConverter, Map
 
-from superset.tags.models import ObjectTypes
+from superset.tags.models import ObjectType
 
 
 class RegexConverter(BaseConverter):
@@ -31,7 +31,7 @@ class ObjectTypeConverter(BaseConverter):
     """Validate that object_type is indeed an object type."""
 
     def to_python(self, value: str) -> Any:
-        return ObjectTypes[value]
+        return ObjectType[value]
 
     def to_url(self, value: Any) -> str:
         return value.name
