@@ -26,6 +26,18 @@ get_recent_activity_schema = {
     },
 }
 
+openapi_spec_methods_override = {
+    "get": {"get": {"summary": "Get a log detail information"}},
+    "get_list": {
+        "get": {
+            "summary": "Get a list of logs",
+            "description": "Gets a list of logs, use Rison or JSON query "
+            "parameters for filtering, sorting, pagination and "
+            " for selecting specific columns and metadata.",
+        }
+    },
+}
+
 
 class RecentActivitySchema(Schema):
     action = fields.String(
