@@ -1668,6 +1668,7 @@ def test_email_dashboard_report_fails_uncaught_exception(
 
     screenshot_mock.return_value = SCREENSHOT_FILE
     email_mock.side_effect = Exception("Uncaught exception")
+    app.config["EMAIL_REPORTS_CTA"] = "Call to action"
 
     with pytest.raises(Exception):
         AsyncExecuteReportScheduleCommand(
@@ -1675,6 +1676,11 @@ def test_email_dashboard_report_fails_uncaught_exception(
         ).run()
 
     assert_log(ReportState.ERROR, error_message="Uncaught exception")
+    assert (
+        '<a href="http://0.0.0.0:8080/superset/dashboard/'
+        f"{create_report_email_dashboard.dashboard.uuid}/"
+        '?force=false">Call to action</a>' in email_mock.call_args[0][2]
+    )
 
 
 @pytest.mark.usefixtures(
