@@ -16,7 +16,7 @@
 # under the License.
 from flask_appbuilder.security.sqla.models import User
 from pytest import raises
-from pytest_mock import MockFixture
+from pytest_mock import MockerFixture
 
 from superset.commands.chart.exceptions import (
     ChartAccessDeniedError,
@@ -28,8 +28,6 @@ from superset.commands.dataset.exceptions import (
 )
 from superset.commands.exceptions import (
     DatasourceNotFoundValidationError,
-    DatasourceTypeInvalidError,
-    OwnersNotFoundValidationError,
     QueryNotFoundValidationError,
 )
 from superset.exceptions import SupersetSecurityException
@@ -62,7 +60,7 @@ def test_unsaved_chart_no_dataset_id() -> None:
             )
 
 
-def test_unsaved_chart_unknown_dataset_id(mocker: MockFixture) -> None:
+def test_unsaved_chart_unknown_dataset_id(mocker: MockerFixture) -> None:
     from superset.explore.utils import check_access as check_chart_access
 
     with raises(DatasetNotFoundError):
@@ -76,7 +74,7 @@ def test_unsaved_chart_unknown_dataset_id(mocker: MockFixture) -> None:
             )
 
 
-def test_unsaved_chart_unknown_query_id(mocker: MockFixture) -> None:
+def test_unsaved_chart_unknown_query_id(mocker: MockerFixture) -> None:
     from superset.explore.utils import check_access as check_chart_access
 
     with raises(QueryNotFoundValidationError):
@@ -90,7 +88,7 @@ def test_unsaved_chart_unknown_query_id(mocker: MockFixture) -> None:
             )
 
 
-def test_unsaved_chart_unauthorized_dataset(mocker: MockFixture) -> None:
+def test_unsaved_chart_unauthorized_dataset(mocker: MockerFixture) -> None:
     from superset.connectors.sqla.models import SqlaTable
     from superset.explore.utils import check_access as check_chart_access
 
@@ -106,7 +104,7 @@ def test_unsaved_chart_unauthorized_dataset(mocker: MockFixture) -> None:
             )
 
 
-def test_unsaved_chart_authorized_dataset(mocker: MockFixture) -> None:
+def test_unsaved_chart_authorized_dataset(mocker: MockerFixture) -> None:
     from superset.connectors.sqla.models import SqlaTable
     from superset.explore.utils import check_access as check_chart_access
 
@@ -121,7 +119,7 @@ def test_unsaved_chart_authorized_dataset(mocker: MockFixture) -> None:
         )
 
 
-def test_saved_chart_unknown_chart_id(mocker: MockFixture) -> None:
+def test_saved_chart_unknown_chart_id(mocker: MockerFixture) -> None:
     from superset.connectors.sqla.models import SqlaTable
     from superset.explore.utils import check_access as check_chart_access
 
@@ -138,7 +136,7 @@ def test_saved_chart_unknown_chart_id(mocker: MockFixture) -> None:
             )
 
 
-def test_saved_chart_unauthorized_dataset(mocker: MockFixture) -> None:
+def test_saved_chart_unauthorized_dataset(mocker: MockerFixture) -> None:
     from superset.connectors.sqla.models import SqlaTable
     from superset.explore.utils import check_access as check_chart_access
 
@@ -154,7 +152,7 @@ def test_saved_chart_unauthorized_dataset(mocker: MockFixture) -> None:
             )
 
 
-def test_saved_chart_is_admin(mocker: MockFixture) -> None:
+def test_saved_chart_is_admin(mocker: MockerFixture) -> None:
     from superset.connectors.sqla.models import SqlaTable
     from superset.explore.utils import check_access as check_chart_access
     from superset.models.slice import Slice
@@ -172,7 +170,7 @@ def test_saved_chart_is_admin(mocker: MockFixture) -> None:
         )
 
 
-def test_saved_chart_is_owner(mocker: MockFixture) -> None:
+def test_saved_chart_is_owner(mocker: MockerFixture) -> None:
     from superset.connectors.sqla.models import SqlaTable
     from superset.explore.utils import check_access as check_chart_access
     from superset.models.slice import Slice
@@ -191,7 +189,7 @@ def test_saved_chart_is_owner(mocker: MockFixture) -> None:
         )
 
 
-def test_saved_chart_has_access(mocker: MockFixture) -> None:
+def test_saved_chart_has_access(mocker: MockerFixture) -> None:
     from superset.connectors.sqla.models import SqlaTable
     from superset.explore.utils import check_access as check_chart_access
     from superset.models.slice import Slice
@@ -211,7 +209,7 @@ def test_saved_chart_has_access(mocker: MockFixture) -> None:
         )
 
 
-def test_saved_chart_no_access(mocker: MockFixture) -> None:
+def test_saved_chart_no_access(mocker: MockerFixture) -> None:
     from superset.connectors.sqla.models import SqlaTable
     from superset.explore.utils import check_access as check_chart_access
     from superset.models.slice import Slice
@@ -232,7 +230,7 @@ def test_saved_chart_no_access(mocker: MockFixture) -> None:
             )
 
 
-def test_dataset_has_access(mocker: MockFixture) -> None:
+def test_dataset_has_access(mocker: MockerFixture) -> None:
     from superset.connectors.sqla.models import SqlaTable
     from superset.explore.utils import check_datasource_access
 
@@ -242,15 +240,15 @@ def test_dataset_has_access(mocker: MockFixture) -> None:
     mocker.patch(is_owner, return_value=False)
     mocker.patch(can_access, return_value=True)
     assert (
-        check_datasource_access(
+        check_datasource_access(  # noqa: E712
             datasource_id=1,
             datasource_type=DatasourceType.TABLE,
         )
-        == True
+        is True
     )
 
 
-def test_query_has_access(mocker: MockFixture) -> None:
+def test_query_has_access(mocker: MockerFixture) -> None:
     from superset.explore.utils import check_datasource_access
     from superset.models.sql_lab import Query
 
@@ -260,21 +258,21 @@ def test_query_has_access(mocker: MockFixture) -> None:
     mocker.patch(is_owner, return_value=False)
     mocker.patch(can_access, return_value=True)
     assert (
-        check_datasource_access(
+        check_datasource_access(  # noqa: E712
             datasource_id=1,
             datasource_type=DatasourceType.QUERY,
         )
-        == True
+        is True
     )
 
 
-def test_query_no_access(mocker: MockFixture, client) -> None:
+def test_query_no_access(mocker: MockerFixture, client) -> None:
     from superset.connectors.sqla.models import SqlaTable
     from superset.explore.utils import check_datasource_access
-    from superset.models.core import Database
     from superset.models.sql_lab import Query
 
     database = mocker.MagicMock()
+    database.get_default_catalog.return_value = None
     database.get_default_schema_for_query.return_value = "public"
     mocker.patch(
         query_find_by_id,
