@@ -30,15 +30,3 @@ class BashMock:
             env={"TEST_ENV": "true"},
         )
         return result
-
-    @staticmethod
-    def docker_build_push(tag, branch):
-        bash_command = f"./scripts/docker_build_push.sh {tag}"
-        result = subprocess.run(
-            bash_command,
-            shell=True,
-            capture_output=True,
-            text=True,
-            env={"TEST_ENV": "true", "GITHUB_REF": f"refs/heads/{branch}"},
-        )
-        return result
