@@ -16,7 +16,6 @@
 # under the License.
 import subprocess
 from unittest import mock
-from unittest.mock import patch
 
 import pytest
 
@@ -33,7 +32,7 @@ def wrapped(*args, **kwargs):
     "tag, expected_output",
     [
         ("1.0.0", "This release tag 1.0.0 is older than the latest."),
-        ("2.1.0", "Versions are equal\n::set-output name=SKIP_TAG::true"),
+        ("2.1.0", "Versions are equal\n"),
         ("2.1.1", "This release tag 2.1.1 is newer than the latest."),
         ("3.0.0", "This release tag 3.0.0 is newer than the latest."),
         ("2.1.0rc1", "This tag 2.1.0rc1 is not a valid release version. Not tagging."),
@@ -44,7 +43,7 @@ def wrapped(*args, **kwargs):
         ("2.1", "This tag 2.1 is not a valid release version. Not tagging."),
         (
             "does_not_exist",
-            "The tag does_not_exist does not exist. Please use a different tag.\n::set-output name=SKIP_TAG::true",
+            "The tag does_not_exist does not exist. Please use a different tag.\n",
         ),
     ],
 )
